@@ -3,7 +3,7 @@
 # A simple test suite for ccache.
 #
 # Copyright (C) 2002-2007 Andrew Tridgell
-# Copyright (C) 2009-2010 Joel Rosdahl
+# Copyright (C) 2009-2011 Joel Rosdahl
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -176,6 +176,10 @@ base_tests() {
     $CCACHE_COMPILE foo.o -o test 2> /dev/null
     checkstat 'called for link' 2
 
+    testname="preprocessing"
+    $CCACHE_COMPILE -E -c test1.c > /dev/null 2>&1
+    checkstat 'called for preprocessing' 1
+
     testname="multiple"
     $CCACHE_COMPILE -c test1.c test2.c
     checkstat 'multiple source files' 1
@@ -576,6 +580,22 @@ EOF
     checkstat 'cache hit (preprocessed)' 0
     checkstat 'cache miss' 0
 
+    ##################################################################
+    # Check that corrupt manifest files are handled and rewritten.
+    testname="corrupt manifest file"
+    $CCACHE -z >/dev/null
+    manifest_file=`find $CCACHE_DIR -name '*.manifest'`
+    rm $manifest_file
+    touch $manifest_file
+    $CCACHE $COMPILER -c test.c
+    checkstat 'cache hit (direct)' 0
+    checkstat 'cache hit (preprocessed)' 1
+    checkstat 'cache miss' 0
+    $CCACHE $COMPILER -c test.c
+    checkstat 'cache hit (direct)' 1
+    checkstat 'cache hit (preprocessed)' 1
+    checkstat 'cache miss' 0
+
     ##################################################################
     # Compiling with CCACHE_NODIRECT set should generate a preprocessed hit.
     testname="preprocessed hit"
